# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`puppetboard`](#puppetboard): Base class for Puppetboard. Sets up the user and python environment.
* [`puppetboard::apache::conf`](#puppetboardapacheconf): Creates an entry in your apache configuration directory to run PuppetBoard server-wide (i.e. not in a vhost).
* [`puppetboard::apache::vhost`](#puppetboardapachevhost): Sets up an apache::vhost to run PuppetBoard, and writes an appropriate wsgi.py from template
* [`puppetboard::params`](#puppetboardparams): == Class: puppetboard::params  Defines default values for puppetboard parameters.  Inherited by Class['puppetboard'].

### Data types

* [`Puppetboard::Syslogpriority`](#puppetboardsyslogpriority): type for the different Python log levels

## Classes

### `puppetboard`

class { 'puppetboard':
   user  => 'pboard',
   group => 'pboard',
   basedir => '/www/puppetboard'
 } ->
 class { 'puppetboard::apache::conf':
   user  => 'pboard',
   group => 'pboard',
   basedir => '/www/puppetboard'
 }

#### Examples

##### 

```puppet
configure puppetboard with an apache config for a subpath (http://$fqdn/puppetboard)
```

#### Parameters

The following parameters are available in the `puppetboard` class.

##### `user`

Data type: `String`

Puppetboard system user.

Default value: `'puppetboard'`

##### `homedir`

Data type: `Optional[Stdlib::Absolutepath]`

Puppetboard system user's home directory.

Default value: ``undef``

##### `group`

Data type: `String`

Puppetboard system group.

Default value: `'puppetboard'`

##### `groups`

Data type: `Optional[Variant[String[1], Array[String[1]]]]`

additional groups for the user that runs puppetboard

Default value: ``undef``

##### `basedir`

Data type: `Stdlib::AbsolutePath`

Base directory where to build puppetboard vcsrepo and python virtualenv.

Default value: `'/srv/puppetboard'`

##### `git_source`

Data type: `String`

Location of upstream Puppetboard GIT repository

Default value: `'https://github.com/voxpupuli/puppetboard'`

##### `puppetdb_host`

Data type: `String`

PuppetDB Host

Default value: `'127.0.0.1'`

##### `puppetdb_port`

Data type: `Stdlib::Port`

PuppetDB Port

Default value: `8080`

##### `puppetdb_key`

Data type: `Optional[Stdlib::AbsolutePath]`

path to PuppetMaster/CA signed client SSL key

Default value: ``undef``

##### `puppetdb_ssl_verify`

Data type: `Variant[Boolean, Stdlib::AbsolutePath]`

whether PuppetDB uses SSL or not (true or false), or the path to the puppet CA

Default value: ``false``

##### `puppetdb_cert`

Data type: `Optional[Stdlib::AbsolutePath]`

path to PuppetMaster/CA signed client SSL cert

Default value: ``undef``

##### `puppetdb_timeout`

Data type: `Integer[0]`

timeout, in seconds, for connecting to PuppetDB

Default value: `20`

##### `dev_listen_host`

Data type: `String`

host that dev server binds to/listens on

Default value: `'127.0.0.1'`

##### `dev_listen_port`

Data type: `Stdlib::Port`

port that dev server binds to/listens on

Default value: `5000`

##### `unresponsive`

Data type: `Integer[0]`

number of hours after which a node is considered "unresponsive"

Default value: `0`

##### `enable_catalog`

Data type: `Boolean`

Whether to allow the user to browser catalog comparisons.

Default value: ``false``

##### `enable_query`

Data type: `Boolean`

Whether to allow the user to run raw queries against PuppetDB.

Default value: ``true``

##### `offline_mode`

Data type: `Boolean`

Weather to load static assents (jquery, semantic-ui, tablesorter, etc)

Default value: ``false``

##### `localise_timestamp`

Data type: `Boolean`

Whether to localise the timestamps in the UI.

Default value: ``true``

##### `python_loglevel`

Data type: `Puppetboard::Syslogpriority`

Python logging module log level.

Default value: `'info'`

##### `python_proxy`

Data type: `Optional[String[1]]`

HTTP proxy server to use for pip/virtualenv.

Default value: ``undef``

##### `python_index`

Data type: `Optional[String[1]]`

HTTP index server to use for pip/virtualenv.

Default value: ``undef``

##### `default_environment`

Data type: `String[1]`

set the default environment

Default value: `'production'`

##### `experimental`

Data type: `Boolean`

Enable experimental features.

Default value: ``false``

##### `revision`

Data type: `Optional[String]`

Commit, tag, or branch from Puppetboard's Git repo to be used

Default value: ``undef``

##### `manage_git`

Data type: `Boolean`

If true, require the git package. If false do nothing.

Default value: ``false``

##### `manage_virtualenv`

Data type: `Boolean`

If true, require the virtualenv package. If false do nothing.

Default value: ``false``

##### `python_version`

Data type: `Pattern[/^3\.\d$/]`

Python version to use in virtualenv.

Default value: `$puppetboard::params::python_version`

##### `virtualenv_dir`

Data type: `Stdlib::Absolutepath`

Set location where virtualenv will be installed

Default value: `"${basedir}/virtenv-puppetboard"`

##### `manage_user`

Data type: `Boolean`

If true, manage (create) this group. If false do nothing.

Default value: ``true``

##### `manage_group`

Data type: `Boolean`

If true, manage (create) this group. If false do nothing.

Default value: ``true``

##### `manage_selinux`

Data type: `Boolean`

If true, manage selinux policies for puppetboard. If false do nothing.

Default value: `$puppetboard::params::manage_selinux`

##### `reports_count`

Data type: `Integer[0]`

This is the number of reports that we want the dashboard to display.

Default value: `10`

##### `listen`

Data type: `Enum['public', 'private']`

If set to 'public' puppetboard will listen on all interfaces

Default value: `'private'`

##### `extra_settings`

Data type: `Hash`

Defaults to an empty hash '{}'. Used to pass in arbitrary key/value

Default value: `{}`

##### `override`

Data type: `String[1]`

Sets the Apache AllowOverride value

Default value: `'None'`

##### `enable_ldap_auth`

Data type: `Boolean`

Whether to enable LDAP auth

Default value: ``false``

##### `ldap_require_group`

Data type: `Boolean`

LDAP group to require on login

Default value: ``false``

##### `apache_confd`

Data type: `Stdlib::Absolutepath`

path to the apache2 vhost directory

Default value: `$puppetboard::params::apache_confd`

##### `apache_service`

Data type: `String[1]`

name of the apache2 service

Default value: `$puppetboard::params::apache_service`

### `puppetboard::apache::conf`

Creates an entry in your apache configuration directory to run PuppetBoard server-wide (i.e. not in a vhost).

* **Note** Make sure you have purge_configs set to false in your apache class!

#### Parameters

The following parameters are available in the `puppetboard::apache::conf` class.

##### `wsgi_alias`

Data type: `Stdlib::Unixpath`

WSGI script alias source

Default value: `'/puppetboard'`

##### `threads`

Data type: `Integer[1]`

Number of WSGI threads to use

Default value: `5`

##### `max_reqs`

Data type: `Integer[0]`

Limit on number of requests allowed to daemon process Defaults to 0 (no limit)

Default value: `0`

##### `user`

Data type: `String[1]`

WSGI daemon process user, and daemon process name

Default value: `$puppetboard::user`

##### `group`

Data type: `String[1]`

WSGI daemon process group owner, and daemon process group

Default value: `$puppetboard::group`

##### `basedir`

Data type: `Stdlib::AbsolutePath`

Base directory where to build puppetboard vcsrepo and python virtualenv.

Default value: `$puppetboard::basedir`

##### `enable_ldap_auth`

Data type: `Boolean`

Whether to enable LDAP auth

Default value: `$puppetboard::enable_ldap_auth`

##### `ldap_bind_dn`

Data type: `Optional[String[1]]`

LDAP Bind DN

Default value: ``undef``

##### `ldap_bind_password`

Data type: `Optional[String[1]]`

LDAP password

Default value: ``undef``

##### `ldap_url`

Data type: `Optional[String[1]]`

LDAP connection string

Default value: ``undef``

##### `ldap_bind_authoritative`

Data type: `Optional[String[1]]`

Determines if other authentication providers are used when a user can be mapped to a DN but the server cannot bind with the credentials

Default value: ``undef``

##### `ldap_require_group`

Data type: `Boolean`

LDAP group to require on login

Default value: `$puppetboard::ldap_require_group`

##### `ldap_require_group_dn`

Data type: `Optional[String[1]]`

LDAP group DN for LDAP group

Default value: ``undef``

### `puppetboard::apache::vhost`

Sets up an apache::vhost to run PuppetBoard, and writes an appropriate wsgi.py from template

#### Parameters

The following parameters are available in the `puppetboard::apache::vhost` class.

##### `vhost_name`

Data type: `String[1]`

The vhost ServerName.

##### `wsgi_alias`

Data type: `Stdlib::Unixpath`

WSGI script alias source

Default value: `'/'`

##### `port`

Data type: `Stdlib::Port`

Port for the vhost to listen on.

Default value: `5000`

##### `ssl`

Data type: `Boolean`

If vhost should be configured with ssl

Default value: ``false``

##### `ssl_cert`

Data type: `Optional[Stdlib::AbsolutePath]`

Path to server SSL cert

Default value: ``undef``

##### `ssl_key`

Data type: `Optional[Stdlib::AbsolutePath]`

Path to server SSL key

Default value: ``undef``

##### `ssl_chain`

Data type: `Optional[Stdlib::AbsolutePath]`

Path to server CA Chain file

Default value: ``undef``

##### `threads`

Data type: `Integer[1]`

Number of WSGI threads to use.

Default value: `5`

##### `user`

Data type: `String[1]`

WSGI daemon process user, and daemon process name

Default value: `$puppetboard::user`

##### `group`

Data type: `String[1]`

WSGI daemon process group owner, and daemon process group

Default value: `$puppetboard::group`

##### `basedir`

Data type: `Stdlib::AbsolutePath`

Base directory where to build puppetboard vcsrepo and python virtualenv.

Default value: `$puppetboard::basedir`

##### `override`

Data type: `String[1]`

Sets the Apache AllowOverride value

Default value: `$puppetboard::apache_override`

##### `enable_ldap_auth`

Data type: `Boolean`

Whether to enable LDAP auth

Default value: `$puppetboard::enable_ldap_auth`

##### `ldap_bind_dn`

Data type: `Optional[String[1]]`

LDAP Bind DN

Default value: ``undef``

##### `ldap_bind_password`

Data type: `Optional[String[1]]`

LDAP password

Default value: ``undef``

##### `ldap_url`

Data type: `Optional[String[1]]`

LDAP connection string

Default value: ``undef``

##### `ldap_bind_authoritative`

Data type: `Optional[String[1]]`

Determines if other authentication providers are used when a user can be mapped to a DN but the server cannot bind with the credentials

Default value: ``undef``

##### `ldap_require_group`

Data type: `Boolean`

LDAP group to require on login

Default value: `$puppetboard::ldap_require_group`

##### `ldap_require_group_dn`

Data type: `Optional[String[1]]`

LDAP group DN for LDAP group

Default value: ``undef``

##### `virtualenv_dir`

Data type: `Stdlib::Absolutepath`

Set location where virtualenv will be installed

Default value: `$puppetboard::virtualenv_dir`

##### `custom_apache_parameters`

Data type: `Hash`

A hash passed to the `apache::vhost` for custom settings

Default value: `{}`

### `puppetboard::params`

== Class: puppetboard::params

Defines default values for puppetboard parameters.

Inherited by Class['puppetboard'].

## Data types

### `Puppetboard::Syslogpriority`

type for the different Python log levels

Alias of `Enum['debug', 'info', 'notice', 'warning', 'err', 'crit', 'alert', 'emerg']`

